@@ -60,7 +60,7 @@ describe('Plugin', () => {
             return '';
         };
 
-        it('calls through to handler on successful auth', async () => {
+        it('handles successful auth', async () => {
 
             const server = Hapi.server();
             await server.register(Hawk);
@@ -83,7 +83,7 @@ describe('Plugin', () => {
             expect(res.result).to.equal('Success');
         });
 
-        it('calls through to handler on failed optional auth', async () => {
+        it('handles failed optional auth', async () => {
 
             const server = Hapi.server();
             await server.register(Hawk);
@@ -105,6 +105,29 @@ describe('Plugin', () => {
             expect(res.result).to.equal('Success');
         });
 
+        it('handles successful auth (default strategy)', async () => {
+
+            const server = Hapi.server();
+            await server.register(Hawk);
+
+            server.auth.strategy('default', 'hawk', { getCredentialsFunc });
+            server.auth.default('default');
+            server.route({
+                method: 'POST',
+                path: '/hawk',
+                handler: function (request, h) {
+
+                    return 'Success';
+                }
+            });
+
+            const request = { method: 'POST', url: 'http://example.com:8080/hawk', headers: { authorization: hawkHeader('john', '/hawk').header } };
+            const res = await server.inject(request);
+
+            expect(res.statusCode).to.equal(200);
+            expect(res.result).to.equal('Success');
+        });
+
         it('includes authorization header in response when the response is a stream', async () => {
 
             const server = Hapi.server();
